/* ********************************************************************** *\
 *         Copyright IBM Corporation 1988,1991 - All Rights Reserved      *
 *        For full copyright information see:'andrew/config/COPYRITE'     *
\* ********************************************************************** */
/*
$Header: /afs/cs.cmu.edu/project/atk-dist/auis-6.3/ams/libs/hdrs/RCS/amsvers.h,v 2.8 1991/09/12 19:15:42 bobg R6tape $
$Source: /afs/cs.cmu.edu/project/atk-dist/auis-6.3/ams/libs/hdrs/RCS/amsvers.h,v $
*/
/* *WARNING*
   The imkfile for the messageserver (andrew/ams/ms) uses the format of this file to determine what name to use in installing the messageserver executable file.  Therefore, DO NOT CHANGE the format of the ``#define'' lines below.
 *WARNING* */
#define AMS_MAJOR_VERSION 10
#define AMS_MINOR_VERSION 3

