/* ********************************************************************** *\
 *         Copyright IBM Corporation 1988,1991 - All Rights Reserved      *
 *        For full copyright information see:'andrew/config/COPYRITE'     *
\* ********************************************************************** */

/*
$Header: /afs/cs.cmu.edu/project/atk-dist/auis-6.3/ams/libs/hdrs/RCS/cuivers.h,v 2.5 1991/09/12 19:15:52 bobg R6tape $
$Source: /afs/cs.cmu.edu/project/atk-dist/auis-6.3/ams/libs/hdrs/RCS/cuivers.h,v $
*/

#define CUI_MAJORVERSION 3
#define CUI_MINORVERSION 45
