/* ********************************************************************** *\
 *         Copyright IBM Corporation 1988,1991 - All Rights Reserved      *
 *        For full copyright information see:'andrew/config/COPYRITE'     *
\* ********************************************************************** */
/*
$Header: /afs/cs.cmu.edu/project/atk-dist/auis-6.3/ams/libs/hdrs/RCS/errlvls.h,v 2.4 1991/09/12 19:15:55 bobg R6tape $
$Source: /afs/cs.cmu.edu/project/atk-dist/auis-6.3/ams/libs/hdrs/RCS/errlvls.h,v $
*/
/*
	Error levels -- should be made obsolete by Andrew standard 
*/

#define MS_CRITICAL 0
#define MS_WARNING 6
#define MS_MONITOR 7
#define MS_DEBUG 8
