/* ********************************************************************** *\
 *         Copyright IBM Corporation 1988,1991 - All Rights Reserved      *
 *        For full copyright information see:'andrew/config/COPYRITE'     *
\* ********************************************************************** */

/*
		qmail.h -- Include file for using qmail subroutines
*/

/* Error returns from qmail routines */

#define Q_OK		1
#define Q_TEMP_FAIL	2
#define Q_BAD_PARMS	3
#define Q_OSERR		4
#define Q_CANT_REWIND	5
#define Q_CANT_CREAT	6
#define Q_FILE_ERR	7
#define Q_NO_PERM	8
#define Q_DIR_ERR	9
