/* andrewos.h

	Define a common environment:  POSIX plus BSD extensions

	system.h includes 
		allsys.h  -- common to all systems
		a number of operating system include files
		site.h   -- specific to a site

	among the operating system include files are 
		types.h, syslog.h, unistd.h, signal.h, param.h, fcntl.h, file.h
		dirXXX.h, stringX.h, timeX.h

*/

#ifndef _ANDREWOS_H_
#define _ANDREWOS_H_

#include <system.h>

#endif /* _ANDREWOS_H_ */
